import 'package:cached_network_image/cached_network_image.dart';
import 'package:expanding_picker_sheet/expanding_picker_sheet.dart';
import 'package:example/picker_screen.dart';
import 'package:example/sheet_thumbnail.dart';
import 'package:example/wallpaper_state_provider.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:flutter_staggered_grid_view/flutter_staggered_grid_view.dart';

class HomeScreen extends StatefulWidget {
  @override
  _HomeScreenState createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen>
    with SingleTickerProviderStateMixin {
  // ExpandingPickerSheet & ExpandingPickerSheet must be initialized
  ExpandingPickerSheet expandingPickerSheet;
  AnimationController _controller;

  @override
  void initState() {
    super.initState();
    // Properly initialize AnimationController
    _controller = AnimationController(
      vsync: this,
      duration: Duration(milliseconds: 450),
      value: 1.0,
    );
  }

  @override
  Widget build(BuildContext context) {
    return Consumer<SheetProvider>(
      builder: (context, sheet, _) {
        // Make sure to intialize and provided Animation Controller, SheetThumbnail and PickerScreen
        expandingPickerSheet = ExpandingPickerSheet(
          hideController: _controller,
          sheetThumbnail: SheetThumbnail(
            iconUrl: sheet.thumbnailUrl,
            listInitial: sheet.thumbnailInitial,
          ),
          pickerScreen: PickerScreen(),
        );

        // Here on Home Screen, show the content which you've selected in the PickerScreen
        return SafeArea(
            // Scaffold and ExpandingPickerSheet must in a Stack Widget
            child: Stack(
          children: <Widget>[
            Scaffold(
              appBar: AppBar(
                title: Text('ExpandingPickerSheetDemo'),
              ),
              body: Center(
                child: sheet.getWallapers().length > 0
                    ? StaggeredGridView.countBuilder(
                        padding: const EdgeInsets.all(10),
                        crossAxisCount: 4,
                        itemCount: sheet.getWallapers().length,
                        itemBuilder: (BuildContext context, int index) {
                          return ClipRRect(
                            borderRadius: BorderRadius.circular(10),
                            child: CachedNetworkImage(
                              imageUrl: sheet.getWallapers()[index].url,
                              fit: BoxFit.cover,
                              placeholder: (context, url) =>
                                  Center(child: CircularProgressIndicator()),
                              errorWidget: (context, url, error) => Center(
                                child: Icon(Icons.error),
                              ),
                            ),
                          );
                        },
                        staggeredTileBuilder: (int index) =>
                            new StaggeredTile.count(2, index.isEven ? 2 : 1),
                        mainAxisSpacing: 10,
                        crossAxisSpacing: 10,
                      )
                    : Text('Click on bottom corner button to load items'),
              ),
            ),

            // Align ExpandingPickerSheet in the Stack at bottom corner
            Align(child: expandingPickerSheet, alignment: Alignment.bottomRight)
          ],
        ));
      },
    );
  }
}
